#!/bin/sh
#stop wlancond
#sleep 1
start wlancond
ifconfig wlan0 up
sleep 1
/usr/bin/advifsw/exec.sh ./post-up